==> libdatetime-locale-perl_1.16.orig.tar.gz: DateTime-Locale-1.16/share/twq-NE.pl <==
{
  am_pm_abbreviated => [
    "Subbaahi",
    "Zaarikay b"
  ],
  available_formats => {
    E => "ccc",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' y"
  },
  code => "twq-NE",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ati",
    "Ata",
    "Ala",
    "Alm",
    "Alz",
    "Asi",
    "Alh"
  ],
  day_format_narrow => [
    "T",
    "T",
    "L",
    "L",
    "L",
    "S",
    "H"
  ],
  day_format_wide => [
    "Atinni",
    "Atalaata",
    "Alarba",
    "Alhamiisa",
    "Alzuma",
    "Asibti",
    "Alhadi"
  ],
  day_stand_alone_abbreviated => [
    "Ati",
    "Ata",
    "Ala",
    "Alm",
    "Alz",
    "Asi",
    "Alh"
  ],
  day_stand_alone_narrow => [
    "T",
    "T",
    "L",
    "L",
    "L",
    "S",
    "H"
  ],
  day_stand_alone_wide => [
    "Atinni",
    "Atalaata",
    "Alarba",
    "Alhamiisa",
    "Alzuma",
    "Asibti",
    "Alhadi"
  ],
  era_abbreviated => [
    "IJ",
    "IZ"
  ],
  era_narrow => [
    "IJ",
    "IZ"
  ],
  era_wide => [
    "Isaa jine",
    "Isaa zamanoo"
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tasawaq",
  month_format_abbreviated => [
    "\N{U+017d}an",
    "Fee",
    "Mar",
    "Awi",
    "Me",
    "\N{U+017d}uw",
    "\N{U+017d}uy",
    "Ut",
    "Sek",
    "Okt",
    "Noo",
    "Dee"
  ],
  month_format_narrow => [
    "\N{U+017d}",
    "F",
    "M",
    "A",
    "M",
    "\N{U+017d}",
    "\N{U+017d}",
    "U",
    "S",
    "O",
    "N",
    "D"
  ],
  month_format_wide => [
    "\N{U+017d}anwiye",
    "Feewiriye",
    "Marsi",
    "Awiril",
    "Me",
    "\N{U+017d}uwe\N{U+014b}",
    "\N{U+017d}uyye",
    "Ut",
    "Sektanbur",
    "Oktoobur",
    "Noowanbur",
    "Deesanbur"
  ],
  month_stand_alone_abbreviated => [
    "\N{U+017d}an",
    "Fee",
    "Mar",
    "Awi",
    "Me",
    "\N{U+017d}uw",
    "\N{U+017d}uy",
    "Ut",
    "Sek",
    "Okt",
    "Noo",
    "Dee"
  ],
  month_stand_alone_narrow => [
    "\N{U+017d}",
    "F",
    "M",
    "A",
    "M",
    "\N{U+017d}",
    "\N{U+017d}",
    "U",
    "S",
    "O",
    "N",
    "D"
  ],
  month_stand_alone_wide => [
    "\N{U+017d}anwiye",
    "Feewiriye",
    "Marsi",
    "Awiril",
    "Me",
    "\N{U+017d}uwe\N{U+014b}",
    "\N{U+017d}uyye",
    "Ut",
    "Sektanbur",
    "Oktoobur",
    "Noowanbur",
    "Deesanbur"
  ],
  name => "Tasawaq Niger",
  native_language => "Tasawaq senni",
  native_name => "Tasawaq senni Ni\N{U+017e}er",
  native_script => undef,
  native_territory => "Ni\N{U+017e}er",
  native_variant => undef,
  quarter_format_abbreviated => [
    "A1",
    "A2",
    "A3",
    "A4"
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_format_wide => [
    "Arrubu 1",
    "Arrubu 2",
    "Arrubu 3",
    "Arrubu 4"
  ],
  quarter_stand_alone_abbreviated => [
    "A1",
    "A2",
    "A3",
    "A4"
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4
  ],
  quarter_stand_alone_wide => [
    "Arrubu 1",
    "Arrubu 2",
    "Arrubu 3",
    "Arrubu 4"
  ],
  script => undef,
  territory => "Niger",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 31
}

==> libdatetime-locale-perl_1.17.orig.tar.gz: DateTime-Locale-1.17/share/twq-NE.pl <==
{
  am_pm_abbreviated => [
    "Subbaahi",
    "Zaarikay b",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "E d",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "'week' W 'of' MMMM",
    MMMMd => "MMMM d",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "m:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "y MMMM",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "twq-NE",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Ati",
    "Ata",
    "Ala",
    "Alm",
    "Alz",
    "Asi",
    "Alh",
  ],
  day_format_narrow => [
    "T",
    "T",
    "L",
    "L",
    "L",
    "S",
    "H",
  ],
  day_format_wide => [
    "Atinni",
    "Atalaata",
    "Alarba",
    "Alhamiisa",
    "Alzuma",
    "Asibti",
    "Alhadi",
  ],
  day_stand_alone_abbreviated => [
    "Ati",
    "Ata",
    "Ala",
    "Alm",
    "Alz",
    "Asi",
    "Alh",
  ],
  day_stand_alone_narrow => [
    "T",
    "T",
    "L",
    "L",
    "L",
    "S",
    "H",
  ],
  day_stand_alone_wide => [
    "Atinni",
    "Atalaata",
    "Alarba",
    "Alhamiisa",
    "Alzuma",
    "Asibti",
    "Alhadi",
  ],
  era_abbreviated => [
    "IJ",
    "IZ",
  ],
  era_narrow => [
    "IJ",
    "IZ",
  ],
  era_wide => [
    "Isaa jine",
    "Isaa zamanoo",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Tasawaq",
  month_format_abbreviated => [
    "\N{U+017d}an",
    "Fee",
    "Mar",
    "Awi",
    "Me",
    "\N{U+017d}uw",
    "\N{U+017d}uy",
    "Ut",
    "Sek",
    "Okt",
    "Noo",
    "Dee",
  ],
  month_format_narrow => [
    "\N{U+017d}",
    "F",
    "M",
    "A",
    "M",
    "\N{U+017d}",
    "\N{U+017d}",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "\N{U+017d}anwiye",
    "Feewiriye",
    "Marsi",
    "Awiril",
    "Me",
    "\N{U+017d}uwe\N{U+014b}",
    "\N{U+017d}uyye",
    "Ut",
    "Sektanbur",
    "Oktoobur",
    "Noowanbur",
    "Deesanbur",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+017d}an",
    "Fee",
    "Mar",
    "Awi",
    "Me",
    "\N{U+017d}uw",
    "\N{U+017d}uy",
    "Ut",
    "Sek",
    "Okt",
    "Noo",
    "Dee",
  ],
  month_stand_alone_narrow => [
    "\N{U+017d}",
    "F",
    "M",
    "A",
    "M",
    "\N{U+017d}",
    "\N{U+017d}",
    "U",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "\N{U+017d}anwiye",
    "Feewiriye",
    "Marsi",
    "Awiril",
    "Me",
    "\N{U+017d}uwe\N{U+014b}",
    "\N{U+017d}uyye",
    "Ut",
    "Sektanbur",
    "Oktoobur",
    "Noowanbur",
    "Deesanbur",
  ],
  name => "Tasawaq Niger",
  native_language => "Tasawaq senni",
  native_name => "Tasawaq senni Ni\N{U+017e}er",
  native_script => undef,
  native_territory => "Ni\N{U+017e}er",
  native_variant => undef,
  quarter_format_abbreviated => [
    "A1",
    "A2",
    "A3",
    "A4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Arrubu 1",
    "Arrubu 2",
    "Arrubu 3",
    "Arrubu 4",
  ],
  quarter_stand_alone_abbreviated => [
    "A1",
    "A2",
    "A3",
    "A4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Arrubu 1",
    "Arrubu 2",
    "Arrubu 3",
    "Arrubu 4",
  ],
  script => undef,
  territory => "Niger",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 32,
}
